==> salmonjs-0.4.1.tgz: package/src/upload.js <==
/**
 *               __                         _____ _______
 * .-----.---.-.|  |.--------.-----.-----._|     |     __|
 * |__ --|  _  ||  ||        |  _  |     |       |__     |
 * |_____|___._||__||__|__|__|_____|__|__|_______|_______|
 *
 * salmonJS v0.4.0
 *
 * Copyright (C) 2013 Fabio Cicerchia <info@fabiocicerchia.it>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

var request = require('request'),
    fs      = require('fs'),
    path    = require('path'),
    args    = process.argv,
    url     = args[2],
    data    = JSON.parse(args[3]),
    options = {
        uri: url,
        timeout: 5000,
        headers: {
            'User-Agent': 'salmonJS/0.4.0 (+http://fabiocicerchia.github.io/salmonjs)'
        }
    },
    req,
    form,
    i;

var handler = function (err, response, body) {
    console.log(body);
};

req  = request.post(options, handler);
form = req.form();

for (i in data) {
    if (data[i].toString().substr(0, 1) === '@') {
        form.append(i, fs.createReadStream(path.resolve(data[i].substr(1))));
    } else {
        form.append(i, data[i]);
    }
}

==> salmonjs-0.5.0.tgz: package/src/upload.js <==
/**
 *               __                         _____ _______
 * .-----.---.-.|  |.--------.-----.-----._|     |     __|
 * |__ --|  _  ||  ||        |  _  |     |       |__     |
 * |_____|___._||__||__|__|__|_____|__|__|_______|_______|
 *
 * salmonJS v0.5.0
 *
 * Copyright (C) 2014 Fabio Cicerchia <info@fabiocicerchia.it>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

var request = require('request'),
    fs      = require('fs'),
    path    = require('path'),
    args    = process.argv,
    url     = args[2],
    data    = JSON.parse(args[3]),
    options = {
        uri: url,
        timeout: 5000,
        headers: {
            'User-Agent': 'salmonJS/0.5.0 (+http://www.salmonjs.org)'
        }
    },
    req,
    form,
    i;

var handler = function (err, response, body) {
    console.log(body);
};

req  = request.post(options, handler);
form = req.form();

for (i in data) {
    if (data[i].toString().substr(0, 1) === '@') {
        form.append(i, fs.createReadStream(path.resolve(data[i].substr(1))));
    } else {
        form.append(i, data[i]);
    }
}
